initMenkDB function
void
initMenkDB()
init menk word database.
This library is using asset files sqlite3.wasm and menk_ime.db.
On the Web, these asset files may freeze your web app server because these
files are too large and load from the web app server. In that case,
I recommend you upload all asset files to your CDN server and customize
initializing the engine using initializeEnginemethod with assetBase
parameter, see this for more details.
Implementation
void initMenkDB() {
internalMenkDBInit();
}